@@ -11,5 +11,10 @@ oz.options(
     cookie_secret = dict(type=str, help="Secret used for secure cookies. Required if you set xsrf_cookies=True."),
     gzip = dict(type=bool, help="Enables gzip output."),
     wsgi_mode = dict(type=bool, default=False, help="Use WSGI mode."),
-    server_workers = dict(type=int, default=1, help="The number of server workers to run concurrently.")
+    server_workers = dict(type=int, default=1, help="The number of server workers to run concurrently."),
+
+    ssl_cert_file = dict(type=str, default=None, help="The SSL certificate file. If unspecified, SSL support will be disabled."),
+    ssl_key_file = dict(type=str, default=None, help="The SSL key file. If unspecified, SSL support will be disabled."),
+    ssl_cert_reqs = dict(type=int, default=0, help="Whether certificates are required from the other side of the connection. 0 = certificates ignored, 1 = certificates optional, 2 = certificates required."),
+    ssl_ca_certs = dict(type=str, default=None, help="SSL CA certificates file.")
 )
\ No newline at end of file
